; rbsp efw waveform crib
;
; Kris Kersten, UMN, May 2012


; initialize RBSP environment
rbsp_efw_init


; set desired probe
; note: probe can be string 'a' or 'b' for a single probe, or string
;		array ['a', 'b'] or space-delimited list 'a b' for both probes.
probe = 'a b'


; set time of interest to a single day
date = '2013-02-15'	; UTC.
duration = 1	; days.
timespan, date, duration


; load data
; note:	datatype can be any subset of the valid types listed below. You can
;		omit datatype in the rbsp_load_efw_waveform call to load all
;		available quantities.  The high time-resolution b1 and b2 quantities
;		can be slow to load and consume significant memory when loaded, so it's
;		best to specify just the *svy variables when looking at surveys over
;		long intervals.
;       
datatype = ['esvy', 'vsvy', 'magsvy', 'eb1', 'vb1', 'mscb1', $
			'eb2', 'vb2', 'mscb2']

; include support data?
get_support_data = 0 ; 0=no, 1=yes


rbsp_load_efw_waveform, probe=probe, datatype=datatype, $
		get_support_data=get_support_data


; list all loaded quantities
tplot_names
; note: At this point all variables all hold combined multi-component data.




;-------------------------------------------------------------------------------
; note: eb2 and mscb2 by default return the three-component U, V, W vector.
;		They can both be commanded to return U, V, W + parallel and perp
;		components.  We have to figure out if we have 3 or 5 components before
;		splitting/labeling the combined vars.

eb2_labels=['E12(U)', 'E34(V)', 'E56(W)']
mscb2_labels=['U', 'V', 'W']
b2_colors=[2, 4, 6]

rbspa_eb2_labels=eb2_labels
rbspb_eb2_labels=eb2_labels
rbspa_mscb2_labels=mscb2_labels
rbspb_mscb2_labels=mscb2_labels

rbspa_eb2_colors=b2_colors
rbspb_eb2_colors=b2_colors
rbspa_mscb2_colors=b2_colors
rbspb_mscb2_colors=b2_colors

; RBSPA eb2
tnames=''
tplot_names,'rbspa_efw_eb2',names=tnames
if tnames ne '' then begin
	get_data,'rbspa_efw_eb2',data=dtemp
	if size(dtemp.v,/n_elements) eq 5 then begin
		rbspa_eb2_labels=[rbspa_eb2_labels, 'Epar', 'Eperp']
		rbspa_eb2_colors=[rbspa_eb2_colors, 1, 3]
	endif
endif

; RBSPB eb2
tnames=''
tplot_names,'rbspb_efw_eb2',names=tnames
if tnames ne '' then begin
	get_data,'rbspb_efw_eb2',data=dtemp
	if size(dtemp.v,/n_elements) eq 5 then begin
		rbspb_eb2_labels=[rbspb_eb2_labels, 'Epar', 'Eperp']
		rbspb_eb2_colors=[rbspb_eb2_colors, 1, 3]
	endif
endif

; RBSPA mscb2
tnames=''
tplot_names,'rbspa_efw_mscb2',names=tnames
if tnames ne '' then begin
	get_data,'rbspa_efw_mscb2',data=dtemp
	if size(dtemp.v,/n_elements) eq 5 then begin
		rbspa_mscb2_labels=[rbspa_mscb2_labels, 'par', 'perp']
		rbspa_mscb2_colors=[rbspa_mscb2_colors, 1, 3]
	endif
endif

; RBSPB mscb2
tnames=''
tplot_names,'rbspb_efw_mscb2',names=tnames
if tnames ne '' then begin
	get_data,'rbspb_efw_mscb2',data=dtemp
	if size(dtemp.v,/n_elements) eq 5 then begin
		rbspb_mscb2_labels=[rbspb_mscb2_labels, 'par', 'perp']
		rbspb_mscb2_colors=[rbspb_mscb2_colors, 1, 3]
	endif
endif
;-------------------------------------------------------------------------------




; add labels and change the colors of each trace in the combined plots

; survey
options, 'rbsp?_efw_esvy', 'colors', [2, 4, 6]
options, 'rbsp?_efw_esvy', 'labels', ['E12(U)', 'E34(V)', 'E56(W)']
options, 'rbsp?_efw_esvy', 'labflag', 1
; note: The 'labflag' option controls the position of labels in the right
;		margin.  Here is the key:
;		0: no labels
;		1: evenly spaced labels
;		2: labels positioned where each trace crosses y-axis
;		-1: evenly space, reversed

options, 'rbsp?_efw_vsvy', 'colors', [ 1, 2, 3, 4, 5, 6]
options, 'rbsp?_efw_vsvy', 'labels', 'V'+['1','2','3','4','5','6']
options, 'rbsp?_efw_vsvy', 'labflag', 1

options, 'rbsp?_efw_magsvy', 'colors', [ 2, 4, 6]
options, 'rbsp?_efw_magsvy', 'labels', ['U', 'V', 'W']
options, 'rbsp?_efw_magsvy', 'labflag', 1

; B1
options, 'rbsp?_efw_eb1', 'colors', [2, 4, 6]
options, 'rbsp?_efw_eb1', 'labels', ['E12(U)', 'E34(V)', 'E56(W)']
options, 'rbsp?_efw_eb1', 'labflag', 1

options, 'rbsp?_efw_vb1', 'colors', [ 1, 2, 3, 4, 5, 6]
options, 'rbsp?_efw_vb1', 'labels', 'V'+['1','2','3','4','5','6']
options, 'rbsp?_efw_vb1', 'labflag', 1

options, 'rbsp?_efw_mscb1', 'colors', [ 2, 4, 6]
options, 'rbsp?_efw_mscb1', 'labels', ['U', 'V', 'W']
options, 'rbsp?_efw_mscb1', 'labflag', 1

; B2
options, 'rbspa_efw_eb2', 'colors', rbspa_eb2_colors
options, 'rbspa_efw_eb2', 'labels', rbspa_eb2_labels
options, 'rbspb_efw_eb2', 'colors', rbspb_eb2_colors
options, 'rbspb_efw_eb2', 'labels', rbspb_eb2_labels
options, 'rbsp?_efw_eb2', 'labflag', 1

options, 'rbsp?_efw_vb2', 'colors', [ 1, 2, 3, 4, 5, 6]
options, 'rbsp?_efw_vb2', 'labels', 'V'+['1','2','3','4','5','6']
options, 'rbsp?_efw_vb2', 'labflag', 1

options, 'rbspa_efw_mscb2', 'colors', rbspa_mscb2_colors
options, 'rbspa_efw_mscb2', 'labels', rbspa_mscb2_labels
options, 'rbspb_efw_mscb2', 'colors', rbspb_mscb2_colors
options, 'rbspb_efw_mscb2', 'labels', rbspb_mscb2_labels
options, 'rbsp?_efw_mscb2', 'labflag', 1


; break the combined variables into individual waveforms
split_vec, 'rbsp?_efw_esvy', suffix='_'+['E12(U)', 'E34(V)', 'E56(W)']
split_vec, 'rbsp?_efw_vsvy', suffix='_V'+['1','2','3','4','5','6']
split_vec, 'rbsp?_efw_magsvy', suffix='_'+['U', 'V', 'W']
split_vec, 'rbsp?_efw_eb1', suffix='_'+['E12(U)', 'E34(V)', 'E56(W)']
split_vec, 'rbsp?_efw_vb1', suffix='_V'+['1','2','3','4','5','6']
split_vec, 'rbsp?_efw_mscb1', suffix='_'+['U', 'V', 'W']
split_vec, 'rbspa_efw_eb2', suffix='_'+rbspa_eb2_labels
split_vec, 'rbspb_efw_eb2', suffix='_'+rbspb_eb2_labels
split_vec, 'rbsp?_efw_vb2', suffix='_V'+['1','2','3','4','5','6']
split_vec, 'rbspa_efw_mscb2', suffix='_'+rbspa_mscb2_labels
split_vec, 'rbspb_efw_mscb2', suffix='_'+rbspb_mscb2_labels


; PLOT

; first format the plot panels
tplot_options, 'xmargin', [ 20., 15.] ; increase margins so we don't lose labels

; add gridlines?
;tplot_options, 'xticklen', 1. ; 100% length for gridlines, set both x,y by using 'ticklen'
;tplot_options, 'xgridstyle', 1
;tplot_options, 'yticklen', 1.
;tplot_options, 'ygridstyle', 1


; waveform summary plots for each spacecraft
;-------------------------------------------------------------------------------
tplot_options,'title','RBSPA waveform summary - ' + date
; note: Title is persistent.  Change it when changing plot quantities.
tplot,['rbspa_efw_*svy', 'rbspa_efw_*b1', 'rbspa_efw_*b2'] ; RBSPA

tplot_options,'title','RBSPB waveform summary - ' + date
tplot,['rbspb_efw_*svy', 'rbspb_efw_*b1', 'rbspb_efw_*b2'] ; RBSPB
;-------------------------------------------------------------------------------


; dump summary plots to PostScript using popen, pclose
popen,'RBSPA_waveform_summary_'+strcompress(date,/remove_all),/port
tplot_options,'title','RBSPA waveform summary - ' + date
tplot,['rbspa_efw_*svy', 'rbspa_efw_*b1', 'rbspa_efw_*b2'] ; RBSPA
pclose

popen,'RBSPB_waveform_summary_'+strcompress(date,/remove_all),/port
tplot_options,'title','RBSPB waveform summary - ' + date
tplot,['rbspb_efw_*svy', 'rbspb_efw_*b1', 'rbspb_efw_*b2'] ; RBSPB
pclose


; combined RBSPA/B plots for individual quantities
tplot_options,'title','RBSP survey - '+date ; set title (this is persistent)
tplot,'rbsp?_efw_*svy' ; all survey quantities, combined line plots
tplot_options,'title','RBSP B1 - '+date
tplot,'rbsp?_efw_*b1' ; all B1 quantities, combined line plots
tplot_options,'title','RBSP B2 - '+date
tplot,'rbsp?_efw_*b2' ; all B2 quantities, combined line plots


; survey, B1, and B2 split line plots for each spacecraft
tplot_options,'title','' ; turn off plot title

; RBSPA
tplot,'rbspa_efw_esvy_*' ; RBSPA E survey, split line plots
tplot,'rbspa_efw_vsvy_V*' ; RBSPA V survey, split line plots
tplot,'rbspa_efw_magsvy_*' ; RBSPA MAG survey, split line plots

tplot,'rbspa_efw_eb1_*' ; RBSPA E B1, split line plots
tplot,'rbspa_efw_vb1_V*' ; RBSPA V B1, split line plots
tplot,'rbspa_efw_mscb1_*' ; RBSPA MSC B1, split line plots

tplot,'rbspa_efw_eb2_*' ; RBSPA E survey, split line plots
tplot,'rbspa_efw_vb2_V*' ; RBSPA V survey, split line plots
tplot,'rbspa_efw_mscb2_*' ; RBSPA MSC B2, split line plots

; RBSPB
tplot,'rbspb_efw_esvy_*' ; RBSPB E survey, split line plots
tplot,'rbspb_efw_vsvy_V*' ; RBSPB V survey, split line plots
tplot,'rbspb_efw_magsvy_*' ; RBSPB MAG survey, split line plots

tplot,'rbspb_efw_eb1_*' ; RBSPB E B1, split line plots
tplot,'rbspb_efw_vb1_V*' ; RBSPB V B1, split line plots
tplot,'rbspb_efw_mscb1_*' ; RBSPB MSC B1, split line plots

tplot,'rbspb_efw_eb2_*' ; RBSPB E survey, split line plots
tplot,'rbspb_efw_vb2_V*' ; RBSPB V survey, split line plots
tplot,'rbspb_efw_mscb2_*' ; RBSPB MSC B2, split line plots



; delete all loaded quantities (this can be useful if you want to look at
; an entirely different day)
;store_data, '*', /delete



end ; rbsp_efw_waveform_crib